[![Documentation Status](https://readthedocs.org/projects/ducktape/badge/?version=0.10.x)](https://ducktape.readthedocs.io/en/0.10.x/?badge=0.10.x)


Distributed System Integration & Performance Testing Library
============================================================

Overview
--------

Ducktape contains tools for running system integration and performance tests. It provides the following features:

* Isolation by default so system tests are as reliable as possible.
* Utilities for pulling up and tearing down services easily in clusters in different environments
  (e.g. local, custom cluster, Vagrant, K8s, Mesos, Docker, cloud providers, etc.)
* Easy to write unit tests for distributed systems
* Trigger special events (e.g. bouncing a service)
* Collect results (e.g. logs, console output)
* Report results (e.g. expected conditions met, performance results, etc.)

Documentation
-------------

For detailed documentation on how to install, run, create new tests please refer to: http://ducktape.readthedocs.io/

Contribute
----------

- Source Code: https://github.com/confluentinc/ducktape
- Issue Tracker: https://github.com/confluentinc/ducktape/issues

License
-------
The project is licensed under the Apache 2 license.
